@@ -1,8 +1,6 @@
 /*
- * $Id: lm-icmp.c,v 1.9 2004/10/08 22:56:58 jylefort Exp $
- *
- * Copyright (c) 1989, 1993 The Regents of the University of California
- * Copyright (c) 2004 Jean-Yves Lefort
+ * Copyright (C) 1989, 1993 The Regents of the University of California
+ * Copyright (C) 2004, 2005 Jean-Yves Lefort
  *
  * All rights reserved.
  *
@@ -52,7 +50,7 @@
 #include <netinet/icmp6.h>
 #endif /* WITH_IPV6 */
 #include <glib.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include "lm-icmp.h"
 #include "lm-sockets.h"
 #include "lm-main.h"
@@ -138,15 +136,17 @@ lm_icmp_in_cksum (u_short *addr, int len)
 }
 
 gboolean
-lm_icmp_send_echo_request (const struct addrinfo *addrinfo,
+lm_icmp_send_echo_request (const LMSocket *sock,
+			   const struct addrinfo *addrinfo,
 			   unsigned int seq,
 			   GError **err)
 {
   char buf[MAX(ICMP_PACKET_LEN, ICMP6_PACKET_LEN)];
   size_t packet_len;
-  const LMSocket *s;
   ssize_t sent_len;
 
+  g_return_val_if_fail(sock != NULL, FALSE);
+  g_return_val_if_fail(sock->init_error == FALSE, FALSE);
   g_return_val_if_fail(addrinfo != NULL, FALSE);
   
   if (addrinfo->ai_family == AF_INET)
@@ -179,13 +179,10 @@ lm_icmp_send_echo_request (const struct addrinfo *addrinfo,
     }
 #endif /* WITH_IPV6 */
   else
-    g_return_val_if_reached(FALSE); /* handled by pa_host_constructor() */
+    g_return_val_if_reached(FALSE);
   
-  s = lm_sockets_get_by_domain(addrinfo->ai_family);
-  g_return_val_if_fail(s != NULL, FALSE);
-
   do
-    sent_len = sendto(s->s, buf, packet_len, 0, addrinfo->ai_addr, addrinfo->ai_addrlen);
+    sent_len = sendto(sock->desc, buf, packet_len, 0, addrinfo->ai_addr, addrinfo->ai_addrlen);
   while (sent_len < 0 && errno == EINTR);
 
   if (sent_len != packet_len)
@@ -304,17 +301,18 @@ lm_icmp_describe_packet6 (struct icmp6_hdr *icmp6)
 #endif /* WITH_IPV6 */
 
 gboolean
-lm_icmp_receive (const LMSocket *s, LMICMPReply *reply)
+lm_icmp_receive (const LMSocket *sock, LMICMPReply *reply)
 {
   gboolean status = FALSE;
   char buf[MAX(MAX_IP_PACKET_LEN, MAX_ICMP6_PACKET_LEN)];
   ssize_t nbytes;
 
-  g_return_val_if_fail(s != NULL, FALSE);
+  g_return_val_if_fail(sock != NULL, FALSE);
+  g_return_val_if_fail(sock->init_error == FALSE, FALSE);
   g_return_val_if_fail(reply != NULL, FALSE);
 
   do
-    nbytes = recvfrom(s->s, buf, sizeof(buf), 0, NULL, NULL);
+    nbytes = recvfrom(sock->desc, buf, sizeof(buf), 0, NULL, NULL);
   while (nbytes < 0 && errno == EINTR);
 
   if (nbytes > 0)
@@ -324,7 +322,7 @@ lm_icmp_receive (const LMSocket *s, LMICMPReply *reply)
 
       g_get_current_time(&tval_received);
 
-      if (s->domain == AF_INET)
+      if (sock->domain == AF_INET)
 	{
 	  struct ip *ip;
 	  struct icmp *icmp;
@@ -349,7 +347,7 @@ lm_icmp_receive (const LMSocket *s, LMICMPReply *reply)
 	    }
 	}
 #ifdef WITH_IPV6
-      else if (s->domain == AF_INET6)
+      else if (sock->domain == AF_INET6)
 	{
 	  struct icmp6_hdr *icmp6;
 
