@@ -1,7 +1,5 @@
 /*
- * $Id: lm-main.c,v 1.4 2004/08/21 21:23:53 jylefort Exp $
- *
- * Copyright (c) 2004 Jean-Yves Lefort
+ * Copyright (C) 2004, 2005 Jean-Yves Lefort
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,6 +37,7 @@
 #include "lm-applet.h"
 #include "lm-sockets.h"
 #include "lm-stock.h"
+#include "lm-util.h"
 
 /*** variables ***************************************************************/
 
@@ -49,6 +48,8 @@ pid_t lm_pid;
 int
 main (int argc, char **argv)
 {
+  GdkPixbuf *icon;
+
   lm_sockets_init1();
 
   /* we don't need root privileges anymore */
@@ -85,5 +86,12 @@ main (int argc, char **argv)
   lm_sockets_init2();
   lm_stock_init();
 
+  icon = lm_pixbuf_new(GNOMEPIXMAPSDIR G_DIR_SEPARATOR_S "link-monitor-applet.png");
+  if (icon)
+    {
+      gtk_window_set_default_icon(icon);
+      g_object_unref(icon);
+    }
+  
   return lm_applet_factory_main();
 }
